@@ -96,7 +96,7 @@ class EcpayCertificate(BaseCertificate):
 
 
 def check_certificate(cert):
-    unverified = jwt.decode(cert, verify=False)
+    unverified = decode(cert, verify=False)
     provider = unverified['provider']
     if provider == 'ecpay':
         cert_class = EcpayCertificate
