@@ -113,7 +113,12 @@ class IssueAction(InvoiceAction):
 
 class EcpayIssue(IssueAction):
     invoice_type = 'ecpay'
-    path = '/ecpay/invoice/issue'
+
+    @property
+    def path(self):
+        if self.category == 'B2B':
+            return '/ecpay/B2B/invoice/issue'
+        return '/ecpay/B2C/invoice/issue'
 
     def map_result(self, data):
         payload = {}
